Index: applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryImage.java
===================================================================
--- applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryImage.java	(revision 31273)
+++ applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryImage.java	(revision 31275)
@@ -21,5 +21,5 @@
 	private long capturedAt;
 	private String user;
-	private List<String> signals;
+	private List<String> signs;
 	private String location;
 
@@ -47,5 +47,5 @@
 		super(lat, lon, ca);
 		this.key = key;
-		this.signals = new ArrayList<>();
+		this.signs = new ArrayList<>();
 	}
 
@@ -59,10 +59,10 @@
 	}
 	
-	public void addSignal(String signal) {
-		signals.add(signal);
+	public void addSign(String sign) {
+		signs.add(sign);
 	}
 	
-	public List<String> getSignals() {
-		return signals;
+	public List<String> getSigns() {
+		return signs;
 	}
 
Index: applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryLayer.java
===================================================================
--- applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryLayer.java	(revision 31273)
+++ applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryLayer.java	(revision 31275)
@@ -112,5 +112,5 @@
 		}
 		MapillaryPlugin.setMenuEnabled(MapillaryPlugin.EXPORT_MENU, true);
-		MapillaryPlugin.setMenuEnabled(MapillaryPlugin.SIGNAL_MENU, true);
+		MapillaryPlugin.setMenuEnabled(MapillaryPlugin.SIGN_MENU, true);
 		Main.map.mapView.setActiveLayer(this);
 		Main.map.repaint();
@@ -161,5 +161,5 @@
 		MapillaryData.INSTANCE = null;
 		MapillaryPlugin.setMenuEnabled(MapillaryPlugin.EXPORT_MENU, false);
-		MapillaryPlugin.setMenuEnabled(MapillaryPlugin.SIGNAL_MENU, false);
+		MapillaryPlugin.setMenuEnabled(MapillaryPlugin.SIGN_MENU, false);
 		MapillaryPlugin.setMenuEnabled(MapillaryPlugin.ZOOM_MENU, false);
 		Main.map.mapView.removeMouseListener(mouseAdapter);
@@ -234,6 +234,6 @@
 						icon = MapillaryPlugin.MAP_ICON_SELECTED;
 					draw(g, image, icon, p);
-					if (!image.getSignals().isEmpty()) {
-						g.drawImage(MapillaryPlugin.MAP_SIGNAL.getImage(), p.x
+					if (!image.getSigns().isEmpty()) {
+						g.drawImage(MapillaryPlugin.MAP_SIGN.getImage(), p.x
 								+ icon.getIconWidth() / 2,
 								p.y - icon.getIconHeight() / 2,
Index: applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryPlugin.java
===================================================================
--- applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryPlugin.java	(revision 31273)
+++ applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/MapillaryPlugin.java	(revision 31275)
@@ -41,5 +41,5 @@
 	public static final ImageIcon MAP_ICON_IMPORTED = new ImageProvider(
 			"mapiconimported.png").get();
-	public static final ImageIcon MAP_SIGNAL = new ImageProvider("signal.png")
+	public static final ImageIcon MAP_SIGN = new ImageProvider("sign.png")
 			.get();
 	public static final int ICON_SIZE = 24;
@@ -50,5 +50,5 @@
 	private final MapillaryExportAction exportAction;
 	private final MapillaryImportAction importAction;
-	private final MapillarySignalAction signalAction;
+	private final MapillarySignAction signAction;
 	private final MapillaryZoomAction zoomAction;
 
@@ -56,5 +56,5 @@
 	public static JMenuItem EXPORT_MENU;
 	public static JMenuItem IMPORT_MENU;
-	public static JMenuItem SIGNAL_MENU;
+	public static JMenuItem SIGN_MENU;
 	public static JMenuItem ZOOM_MENU;
 
@@ -64,5 +64,5 @@
 		exportAction = new MapillaryExportAction();
 		importAction = new MapillaryImportAction();
-		signalAction = new MapillarySignalAction();
+		signAction = new MapillarySignAction();
 		zoomAction = new MapillaryZoomAction();
 
@@ -73,6 +73,6 @@
 		IMPORT_MENU = MainMenu.add(Main.main.menu.fileMenu, importAction,
 				false, 14);
-		SIGNAL_MENU = MainMenu
-				.add(Main.main.menu.dataMenu, signalAction, false);
+		SIGN_MENU = MainMenu
+				.add(Main.main.menu.dataMenu, signAction, false);
 		ZOOM_MENU = MainMenu
 				.add(Main.main.menu.viewMenu, zoomAction, false, 15);
@@ -81,5 +81,5 @@
 		DOWNLOAD_MENU.setEnabled(false);
 		IMPORT_MENU.setEnabled(false);
-		SIGNAL_MENU.setEnabled(false);
+		SIGN_MENU.setEnabled(false);
 		ZOOM_MENU.setEnabled(false);
 
Index: applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/actions/MapillarySignAction.java
===================================================================
--- applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/actions/MapillarySignAction.java	(revision 31275)
+++ applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/actions/MapillarySignAction.java	(revision 31275)
@@ -0,0 +1,35 @@
+package org.openstreetmap.josm.plugins.mapillary.actions;
+
+import static org.openstreetmap.josm.tools.I18n.tr;
+
+import java.awt.event.ActionEvent;
+import java.awt.event.KeyEvent;
+
+import org.openstreetmap.josm.actions.JosmAction;
+import org.openstreetmap.josm.plugins.mapillary.gui.MapillaryToggleDialog;
+import org.openstreetmap.josm.tools.ImageProvider;
+import org.openstreetmap.josm.tools.Shortcut;
+
+/**
+ * Switches the window mode from normal to sign and viceversa.
+ * 
+ * @author nokutu
+ * @see MapillaryToggleDialog
+ *
+ */
+public class MapillarySignAction extends JosmAction {
+
+	public MapillarySignAction() {
+		super(tr("Switch sign/normal mode"), new ImageProvider("icon24sign.png"),
+				tr("Switch sign/normal mode"), Shortcut.registerShortcut(
+						"Mapillary sign", tr("Switch Mapillary plugin's sign mode on/off"),
+						KeyEvent.VK_M, Shortcut.NONE), false,
+				"mapillarySign", false);
+		this.setEnabled(false);
+	}
+
+	@Override
+	public void actionPerformed(ActionEvent e) {
+		MapillaryToggleDialog.getInstance().switchMode();
+	}
+}
Index: applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/actions/MapillarySignalAction.java
===================================================================
--- applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/actions/MapillarySignalAction.java	(revision 31273)
+++ 	(revision )
@@ -1,35 +1,0 @@
-package org.openstreetmap.josm.plugins.mapillary.actions;
-
-import static org.openstreetmap.josm.tools.I18n.tr;
-
-import java.awt.event.ActionEvent;
-import java.awt.event.KeyEvent;
-
-import org.openstreetmap.josm.actions.JosmAction;
-import org.openstreetmap.josm.plugins.mapillary.gui.MapillaryToggleDialog;
-import org.openstreetmap.josm.tools.ImageProvider;
-import org.openstreetmap.josm.tools.Shortcut;
-
-/**
- * Switches the window mode from normal to signal and viceversa.
- * 
- * @author nokutu
- * @see MapillaryToggleDialog
- *
- */
-public class MapillarySignalAction extends JosmAction {
-
-	public MapillarySignalAction() {
-		super(tr("Switch signal mode"), new ImageProvider("icon24signal.png"),
-				tr("Switch signal mode"), Shortcut.registerShortcut(
-						"Mapillary signal", tr("Switch Mapillary plugin's signal mode on/off"),
-						KeyEvent.VK_M, Shortcut.NONE), false,
-				"mapillarySignal", false);
-		this.setEnabled(false);
-	}
-
-	@Override
-	public void actionPerformed(ActionEvent e) {
-		MapillaryToggleDialog.getInstance().switchMode();
-	}
-}
Index: applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/downloads/MapillarySignDownloaderThread.java
===================================================================
--- applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/downloads/MapillarySignDownloaderThread.java	(revision 31275)
+++ applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/downloads/MapillarySignDownloaderThread.java	(revision 31275)
@@ -0,0 +1,82 @@
+package org.openstreetmap.josm.plugins.mapillary.downloads;
+
+import java.io.BufferedReader;
+import java.io.IOException;
+import java.io.InputStreamReader;
+import java.net.MalformedURLException;
+import java.net.URL;
+import java.util.concurrent.ExecutorService;
+
+import javax.json.Json;
+import javax.json.JsonArray;
+import javax.json.JsonObject;
+
+import org.openstreetmap.josm.Main;
+import org.openstreetmap.josm.plugins.mapillary.MapillaryAbstractImage;
+import org.openstreetmap.josm.plugins.mapillary.MapillaryData;
+import org.openstreetmap.josm.plugins.mapillary.MapillaryImage;
+
+public class MapillarySignDownloaderThread implements Runnable {
+
+	private final String url;
+	private final ExecutorService ex;
+
+	public MapillarySignDownloaderThread(ExecutorService ex, String url) {
+		this.ex = ex;
+		this.url = url;
+	}
+
+	@Override
+	public void run() {
+		BufferedReader br;
+		try {
+			br = new BufferedReader(new InputStreamReader(
+					new URL(url).openStream()));
+			JsonObject jsonobj = Json.createReader(br).readObject();
+			if (!jsonobj.getBoolean("more")) {
+				ex.shutdown();
+			}
+			JsonArray jsonarr = jsonobj.getJsonArray("ims");
+			for (int i = 0; i < jsonarr.size(); i++) {
+				JsonArray rects = jsonarr.getJsonObject(i)
+						.getJsonArray("rects");
+				JsonArray rectversions = jsonarr.getJsonObject(i).getJsonArray(
+						"rectversions");
+				String key = jsonarr.getJsonObject(i).getString("key");
+				if (rectversions != null) {
+					for (int j = 0; j < rectversions.size(); j++) {
+						rects = rectversions.getJsonObject(j).getJsonArray("rects");
+						for (int k = 0; k < rects.size(); k++) {
+							JsonObject data = rects.getJsonObject(j);
+							for (MapillaryAbstractImage image : MapillaryData
+									.getInstance().getImages())
+								if (image instanceof MapillaryImage
+										&& ((MapillaryImage) image).getKey()
+												.equals(key))
+									((MapillaryImage) image).addSign(data
+											.getString("type"));
+						}
+					}
+				}
+
+				// Just one sign on the picture
+				else if (rects != null) {
+					for (int j = 0; j < rects.size(); j++) {
+						JsonObject data = rects.getJsonObject(j);
+						for (MapillaryAbstractImage image : MapillaryData
+								.getInstance().getImages())
+							if (image instanceof MapillaryImage
+									&& ((MapillaryImage) image).getKey()
+											.equals(key))
+								((MapillaryImage) image).addSign(data
+										.getString("type"));
+					}
+				}
+			}
+		} catch (MalformedURLException e) {
+			Main.error(e);
+		} catch (IOException e) {
+			Main.error(e);
+		}
+	}
+}
Index: applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/downloads/MapillarySignalDownloaderThread.java
===================================================================
--- applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/downloads/MapillarySignalDownloaderThread.java	(revision 31273)
+++ 	(revision )
@@ -1,82 +1,0 @@
-package org.openstreetmap.josm.plugins.mapillary.downloads;
-
-import java.io.BufferedReader;
-import java.io.IOException;
-import java.io.InputStreamReader;
-import java.net.MalformedURLException;
-import java.net.URL;
-import java.util.concurrent.ExecutorService;
-
-import javax.json.Json;
-import javax.json.JsonArray;
-import javax.json.JsonObject;
-
-import org.openstreetmap.josm.Main;
-import org.openstreetmap.josm.plugins.mapillary.MapillaryAbstractImage;
-import org.openstreetmap.josm.plugins.mapillary.MapillaryData;
-import org.openstreetmap.josm.plugins.mapillary.MapillaryImage;
-
-public class MapillarySignalDownloaderThread implements Runnable {
-
-	private final String url;
-	private final ExecutorService ex;
-
-	public MapillarySignalDownloaderThread(ExecutorService ex, String url) {
-		this.ex = ex;
-		this.url = url;
-	}
-
-	@Override
-	public void run() {
-		BufferedReader br;
-		try {
-			br = new BufferedReader(new InputStreamReader(
-					new URL(url).openStream()));
-			JsonObject jsonobj = Json.createReader(br).readObject();
-			if (!jsonobj.getBoolean("more")) {
-				ex.shutdown();
-			}
-			JsonArray jsonarr = jsonobj.getJsonArray("ims");
-			for (int i = 0; i < jsonarr.size(); i++) {
-				JsonArray rects = jsonarr.getJsonObject(i)
-						.getJsonArray("rects");
-				JsonArray rectversions = jsonarr.getJsonObject(i).getJsonArray(
-						"rectversions");
-				String key = jsonarr.getJsonObject(i).getString("key");
-				if (rectversions != null) {
-					for (int j = 0; j < rectversions.size(); j++) {
-						rects = rectversions.getJsonObject(j).getJsonArray("rects");
-						for (int k = 0; k < rects.size(); k++) {
-							JsonObject data = rects.getJsonObject(j);
-							for (MapillaryAbstractImage image : MapillaryData
-									.getInstance().getImages())
-								if (image instanceof MapillaryImage
-										&& ((MapillaryImage) image).getKey()
-												.equals(key))
-									((MapillaryImage) image).addSignal(data
-											.getString("type"));
-						}
-					}
-				}
-
-				// Just one signal on the picture
-				else if (rects != null) {
-					for (int j = 0; j < rects.size(); j++) {
-						JsonObject data = rects.getJsonObject(j);
-						for (MapillaryAbstractImage image : MapillaryData
-								.getInstance().getImages())
-							if (image instanceof MapillaryImage
-									&& ((MapillaryImage) image).getKey()
-											.equals(key))
-								((MapillaryImage) image).addSignal(data
-										.getString("type"));
-					}
-				}
-			}
-		} catch (MalformedURLException e) {
-			Main.error(e);
-		} catch (IOException e) {
-			Main.error(e);
-		}
-	}
-}
Index: applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/downloads/MapillarySquareDownloadManagerThread.java
===================================================================
--- applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/downloads/MapillarySquareDownloadManagerThread.java	(revision 31273)
+++ applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/downloads/MapillarySquareDownloadManagerThread.java	(revision 31275)
@@ -24,12 +24,12 @@
 	private final String urlImages;
 	private final String urlSequences;
-	private final String urlSignals;
+	private final String urlSigns;
 	private final Bounds bounds;
 
 	public MapillarySquareDownloadManagerThread(String urlImages,
-			String urlSequences, String urlSignals, Bounds bounds) {
+			String urlSequences, String urlSigns, Bounds bounds) {
 		this.urlImages = urlImages;
 		this.urlSequences = urlSequences;
-		this.urlSignals = urlSignals;
+		this.urlSigns = urlSigns;
 		this.bounds = bounds;
 	}
@@ -40,6 +40,6 @@
 			downloadSequences();
 			completeImages();
-			Main.map.statusLine.setHelpText("Downloading signals information");
-			downloadSignals();
+			Main.map.statusLine.setHelpText("Downloading signs information");
+			downloadSigns();
 		} catch (InterruptedException e) {
 			Main.error(e);
@@ -82,10 +82,10 @@
 	}
 
-	private void downloadSignals() throws InterruptedException {
+	private void downloadSigns() throws InterruptedException {
 		ThreadPoolExecutor ex = new ThreadPoolExecutor(3, 5, 25,
 				TimeUnit.SECONDS, new ArrayBlockingQueue<Runnable>(5));
 		int page = 0;
 		while (!ex.isShutdown()) {
-			ex.execute(new MapillarySignalDownloaderThread(ex, urlSignals
+			ex.execute(new MapillarySignDownloaderThread(ex, urlSigns
 					+ "&page=" + page + "&limit=20"));
 			while (ex.getQueue().remainingCapacity() == 0)
Index: applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/gui/MapillaryToggleDialog.java
===================================================================
--- applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/gui/MapillaryToggleDialog.java	(revision 31273)
+++ applications/editors/josm/plugins/mapillary/src/org/openstreetmap/josm/plugins/mapillary/gui/MapillaryToggleDialog.java	(revision 31275)
@@ -46,5 +46,5 @@
 
 	public final static int NORMAL_MODE = 0;
-	public final static int SIGNAL_MODE = 1;
+	public final static int SIGN_MODE = 1;
 
 	public final static String BASE_TITLE = "Mapillary picture";
@@ -61,9 +61,9 @@
 	private List<SideButton> normalMode;
 
-	public final SideButton nextSignalButton = new SideButton(
-			new NextSignalAction());
-	public final SideButton previousSignalButton = new SideButton(
-			new PreviousSignalAction());
-	private List<SideButton> signalMode;
+	public final SideButton nextSignButton = new SideButton(
+			new NextSignAction());
+	public final SideButton previousSignButton = new SideButton(
+			new PreviousSignAction());
+	private List<SideButton> signMode;
 
 	private int mode;
@@ -90,13 +90,9 @@
 		normalMode = Arrays.asList(new SideButton[] { blueButton,
 				previousButton, nextButton, redButton });
-		signalMode = Arrays.asList(new SideButton[] { previousSignalButton,
-				nextSignalButton });
+		signMode = Arrays.asList(new SideButton[] { previousSignButton,
+				nextSignButton });
 
 		mode = NORMAL_MODE;
-		/*
-		 * this.setLayout(new BorderLayout()); top = new JPanel();
-		 * top.setLayout(new BorderLayout()); top.add(titleBar,
-		 * BorderLayout.NORTH);
-		 */
+		
 		createLayout(mapillaryImageDisplay, normalMode,
 				Main.pref.getBoolean("mapillary.reverse-buttons"));
@@ -121,7 +117,7 @@
 		List<SideButton> list = null;
 		if (mode == NORMAL_MODE) {
-			list = signalMode;
-			mode = SIGNAL_MODE;
-		} else if (mode == SIGNAL_MODE) {
+			list = signMode;
+			mode = SIGN_MODE;
+		} else if (mode == SIGN_MODE) {
 			list = normalMode;
 			mode = NORMAL_MODE;
@@ -172,7 +168,7 @@
 					if (mapillaryImage.previous() == null)
 						this.previousButton.setEnabled(false);
-				} else if (mode == SIGNAL_MODE) {
-					previousSignalButton.setEnabled(true);
-					nextSignalButton.setEnabled(true);
+				} else if (mode == SIGN_MODE) {
+					previousSignButton.setEnabled(true);
+					nextSignButton.setEnabled(true);
 					int i = MapillaryData
 							.getInstance()
@@ -187,5 +183,5 @@
 							.getInstance().getImages()) {
 						if (img instanceof MapillaryImage)
-							if (!((MapillaryImage) img).getSignals().isEmpty()) {
+							if (!((MapillaryImage) img).getSigns().isEmpty()) {
 								if (first == -1)
 									first = c;
@@ -195,7 +191,7 @@
 					}
 					if (first >= i)
-						previousSignalButton.setEnabled(false);
+						previousSignButton.setEnabled(false);
 					if (last <= i)
-						nextSignalButton.setEnabled(false);
+						nextSignButton.setEnabled(false);
 				}
 
@@ -235,6 +231,6 @@
 		blueButton.setEnabled(false);
 		redButton.setEnabled(false);
-		nextSignalButton.setEnabled(false);
-		previousSignalButton.setEnabled(false);
+		nextSignButton.setEnabled(false);
+		previousSignButton.setEnabled(false);
 		mapillaryImageDisplay.hyperlink.setVisible(false);
 	}
@@ -418,14 +414,14 @@
 
 	/**
 	 * Action class to jump to the next picture containing a signal.
 	 * 
 	 * @author nokutu
 	 *
 	 */
-	class NextSignalAction extends AbstractAction {
-		public NextSignalAction() {
-			putValue(NAME, tr("Next Signal"));
+	class NextSignAction extends AbstractAction {
+		public NextSignAction() {
+			putValue(NAME, tr("Next Sign"));
 			putValue(SHORT_DESCRIPTION,
-					tr("Jumps to the next picture that contains a signal"));
+					tr("Jumps to the next picture that contains a sign"));
 		}
 
@@ -442,5 +438,5 @@
 							.getImages().get(j);
 					if (img instanceof MapillaryImage)
-						if (!((MapillaryImage) img).getSignals().isEmpty()) {
+						if (!((MapillaryImage) img).getSigns().isEmpty()) {
 							MapillaryData.getInstance().setSelectedImage(img,
 									true);
@@ -453,14 +449,14 @@
 
 	/**
 	 * Action class to jump to the previous picture containing a signal.
 	 * 
 	 * @author nokutu
 	 *
 	 */
-	class PreviousSignalAction extends AbstractAction {
-		public PreviousSignalAction() {
-			putValue(NAME, tr("Previous Signal"));
+	class PreviousSignAction extends AbstractAction {
+		public PreviousSignAction() {
+			putValue(NAME, tr("Previous Sign"));
 			putValue(SHORT_DESCRIPTION,
-					tr("Jumps to the previous picture that contains a signal"));
+					tr("Jumps to the previous picture that contains a sign"));
 		}
 
@@ -476,5 +472,5 @@
 							.getImages().get(j);
 					if (img instanceof MapillaryImage)
-						if (!((MapillaryImage) img).getSignals().isEmpty()) {
+						if (!((MapillaryImage) img).getSigns().isEmpty()) {
 							MapillaryData.getInstance().setSelectedImage(img,
 									true);
@@ -418,14 +414,14 @@
 
 	/**
-	 * Action class to jump to the next picture containing a signal.
+	 * Action class to jump to the next picture containing a sign.
 	 * 
 	 * @author nokutu
@@ -453,14 +449,14 @@
 
 	/**
-	 * Action class to jump to the previous picture containing a signal.
+	 * Action class to jump to the previous picture containing a sign.
 	 * 
 	 * @author nokutu
